===============================
networking-ansible
===============================

Ansible Networking ML2 Driver

Networking-Ansible is a Neutron ML2 driver that abstracts the interaction with
switch hardware to Ansible Networking. This driver may not be tested with all
the modules included with Ansible Networking. In theory it should work with any
switch that has compatible modules included with Ansible Networking.

* Free software: Apache license
* Documentation: https://docs.openstack.org/networking-ansible/latest
* Source: https://git.openstack.org/cgit/openstack/networking-ansible
* Bugs: https://storyboard.openstack.org/#!/project/986

Features
--------

* TODO
